==> estateplat-common-1.2.4-20201113.014416-502-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttZhjbxxBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttZhjbxx;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttZhjbxxBdc extends KttZhjbxx {
    private String dfxmxzdm;
    private String dfxmxzmc;
    private String dfdbdm;
    private String dfdbmc;
    private String dfyhlxadm;
    private String dfyhlxamc;
    private String dfyhlxbdm;
    private String dfyhlxbmc;
    private String dfhdytdm;
    private String dfhdytmc;
    private String dfztdm;
    private String dfztmc;
    @XmlAttribute(
            name = "DFXMXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfxmxzdm() {
        return dfxmxzdm;
    }

    public void setDfxmxzdm(String dfxmxzdm) {
        this.dfxmxzdm = dfxmxzdm;
    }
    @XmlAttribute(
            name = "DFXMXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfxmxzmc() {
        return dfxmxzmc;
    }

    public void setDfxmxzmc(String dfxmxzmc) {
        this.dfxmxzmc = dfxmxzmc;
    }
    @XmlAttribute(
            name = "DFDBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdbdm() {
        return dfdbdm;
    }

    public void setDfdbdm(String dfdbdm) {
        this.dfdbdm = dfdbdm;
    }
    @XmlAttribute(
            name = "DFDBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdbmc() {
        return dfdbmc;
    }

    public void setDfdbmc(String dfdbmc) {
        this.dfdbmc = dfdbmc;
    }
    @XmlAttribute(
            name = "DFYHLXADM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfyhlxadm() {
        return dfyhlxadm;
    }

    public void setDfyhlxadm(String dfyhlxadm) {
        this.dfyhlxadm = dfyhlxadm;
    }
    @XmlAttribute(
            name = "DFYHLXAMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfyhlxamc() {
        return dfyhlxamc;
    }

    public void setDfyhlxamc(String dfyhlxamc) {
        this.dfyhlxamc = dfyhlxamc;
    }
    @XmlAttribute(
            name = "DFYHLXBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfyhlxbdm() {
        return dfyhlxbdm;
    }

    public void setDfyhlxbdm(String dfyhlxbdm) {
        this.dfyhlxbdm = dfyhlxbdm;
    }
    @XmlAttribute(
            name = "DFYHLXBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfyhlxbmc() {
        return dfyhlxbmc;
    }

    public void setDfyhlxbmc(String dfyhlxbmc) {
        this.dfyhlxbmc = dfyhlxbmc;
    }
    @XmlAttribute(
            name = "DFHDYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfhdytdm() {
        return dfhdytdm;
    }

    public void setDfhdytdm(String dfhdytdm) {
        this.dfhdytdm = dfhdytdm;
    }
    @XmlAttribute(
            name = "DFHDYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfhdytmc() {
        return dfhdytmc;
    }

    public void setDfhdytmc(String dfhdytmc) {
        this.dfhdytmc = dfhdytmc;
    }
    @XmlAttribute(
            name = "DFZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfztdm() {
        return dfztdm;
    }

    public void setDfztdm(String dfztdm) {
        this.dfztdm = dfztdm;
    }
    @XmlAttribute(
            name = "DFZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfztmc() {
        return dfztmc;
    }

    public void setDfztmc(String dfztmc) {
        this.dfztmc = dfztmc;
    }
}

==> estateplat-common-1.2.4-20201116.060719-507-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttZhjbxxBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttZhjbxx;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttZhjbxxBdc extends KttZhjbxx {
    private String dfxmxzdm;
    private String dfxmxzmc;
    private String dfdbdm;
    private String dfdbmc;
    private String dfyhlxadm;
    private String dfyhlxamc;
    private String dfyhlxbdm;
    private String dfyhlxbmc;
    private String dfhdytdm;
    private String dfhdytmc;
    private String dfztdm;
    private String dfztmc;
    @XmlAttribute(
            name = "DFXMXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxmxzdm() {
        return dfxmxzdm;
    }

    public void setDfxmxzdm(String dfxmxzdm) {
        this.dfxmxzdm = dfxmxzdm;
    }
    @XmlAttribute(
            name = "DFXMXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfxmxzmc() {
        return dfxmxzmc;
    }

    public void setDfxmxzmc(String dfxmxzmc) {
        this.dfxmxzmc = dfxmxzmc;
    }
    @XmlAttribute(
            name = "DFDBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdbdm() {
        return dfdbdm;
    }

    public void setDfdbdm(String dfdbdm) {
        this.dfdbdm = dfdbdm;
    }
    @XmlAttribute(
            name = "DFDBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdbmc() {
        return dfdbmc;
    }

    public void setDfdbmc(String dfdbmc) {
        this.dfdbmc = dfdbmc;
    }
    @XmlAttribute(
            name = "DFYHLXADM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxadm() {
        return dfyhlxadm;
    }

    public void setDfyhlxadm(String dfyhlxadm) {
        this.dfyhlxadm = dfyhlxadm;
    }
    @XmlAttribute(
            name = "DFYHLXAMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxamc() {
        return dfyhlxamc;
    }

    public void setDfyhlxamc(String dfyhlxamc) {
        this.dfyhlxamc = dfyhlxamc;
    }
    @XmlAttribute(
            name = "DFYHLXBDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxbdm() {
        return dfyhlxbdm;
    }

    public void setDfyhlxbdm(String dfyhlxbdm) {
        this.dfyhlxbdm = dfyhlxbdm;
    }
    @XmlAttribute(
            name = "DFYHLXBMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfyhlxbmc() {
        return dfyhlxbmc;
    }

    public void setDfyhlxbmc(String dfyhlxbmc) {
        this.dfyhlxbmc = dfyhlxbmc;
    }
    @XmlAttribute(
            name = "DFHDYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhdytdm() {
        return dfhdytdm;
    }

    public void setDfhdytdm(String dfhdytdm) {
        this.dfhdytdm = dfhdytdm;
    }
    @XmlAttribute(
            name = "DFHDYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfhdytmc() {
        return dfhdytmc;
    }

    public void setDfhdytmc(String dfhdytmc) {
        this.dfhdytmc = dfhdytmc;
    }
    @XmlAttribute(
            name = "DFZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztdm() {
        return dfztdm;
    }

    public void setDfztdm(String dfztdm) {
        this.dfztdm = dfztdm;
    }
    @XmlAttribute(
            name = "DFZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfztmc() {
        return dfztmc;
    }

    public void setDfztmc(String dfztmc) {
        this.dfztmc = dfztmc;
    }
}
